Documentation
¶
Index ¶
Constants ¶
const (
DefaultName = "env"
)
Variables ¶
This section is empty.
Functions ¶
func NewDefault ¶
Types ¶
type Driver ¶ added in v0.4.3
type Driver struct {
rs.BaseField `yaml:"-"`
renderer.BaseRenderer `yaml:",inline"`
// EnableExec controls arbitrary command execution support when expanding env.
//
// if set to false, expanding env with shell evaluation (e.g. `$(do something)`)
// will be skipped and formatted
//
// NOTE: shell evaluation of backqouted string is always skipped and formatted
//
// Defaults to `false`
EnableExec *bool `yaml:"enable_exec"`
// contains filtered or unexported fields
}
func (*Driver) RenderYaml ¶ added in v0.4.3
func (d *Driver) RenderYaml( rc dukkha.RenderingContext, rawData interface{}, _ []dukkha.RendererAttribute, ) ([]byte, error)
Click to show internal directories.
Click to hide internal directories.